==> vscode-phpfmt-1.0.30.tgz: package/test/extension.test.ts <==
import * as assert from 'assert';
import * as path from 'path';
import { execSync } from 'child_process';
import {
  workspace as Workspace,
  window as Window,
  commands as Commands,
  extensions as Extensions,
  Extension
} from 'vscode';
import phpfmt from 'phpfmt';

const pkg: any = require('pjson');

suite('PHPFmt Test', () => {
  const extension = Extensions.getExtension(
    `${pkg.author}.${pkg.name}`
  ) as Extension<any>;

  test('extension should be present', () => {
    assert.ok(extension);
  });

  test('can activate', () => {
    return extension.activate().then(() => {
      assert.ok(true);
    });
  });

  test('can format with command', () => {
    const filePath: string = path.join(Workspace.rootPath!, 'ugly.php');
    return Workspace.openTextDocument(filePath).then(doc => {
      return Window.showTextDocument(doc).then(() =>
        Commands.executeCommand('editor.action.formatDocument').then(
          () => {
            const stdout: Buffer = execSync(
              `php "${
                phpfmt.pharPath
              }" --psr2 --indent_with_space=4 --dry-run -o=- ${filePath}`
            );
            const phpfmtFormatted: string = stdout.toString();
            assert.equal(doc.getText(), phpfmtFormatted);
          },
          err => console.error(err)
        )
      );
    });
  });

  test('should register commands', () => {
    return Commands.getCommands(true).then(commands => {
      const foundCommands = commands.filter(value =>
        value.startsWith('phpfmt.')
      );

      assert.equal(foundCommands.length, pkg.contributes.commands.length);
    });
  });

  test('should commands work', () => {
    const commands = pkg.contributes.commands as Array<any>;
    commands
      .filter(value => !value.when)
      .forEach(command => Commands.executeCommand(command.command));
  });
});

==> vscode-phpfmt-1.1.1.tgz: package/test/extension.test.ts <==
import assert from 'assert';
import path from 'path';
import { execSync } from 'child_process';
import {
  workspace as Workspace,
  window as Window,
  commands as Commands,
  extensions as Extensions,
  Extension
} from 'vscode';
import phpfmt from 'use-phpfmt';

const pkg: any = require('pjson');

suite('PHPFmt Test', () => {
  const extension = Extensions.getExtension(
    `${pkg.author}.${pkg.name}`
  ) as Extension<any>;

  test('extension should be present', () => {
    assert.ok(extension);
  });

  test('can activate', () => {
    return extension.activate().then(() => {
      assert.ok(true);
    });
  });

  test('can format with command', () => {
    const filePath: string = path.join(Workspace.rootPath!, 'ugly.php');
    return Workspace.openTextDocument(filePath).then(doc => {
      return Window.showTextDocument(doc).then(() =>
        Commands.executeCommand('editor.action.formatDocument').then(
          () => {
            const stdout: Buffer = execSync(
              `php "${phpfmt.pharPath}" --psr2 --indent_with_space=4 --dry-run -o=- ${filePath}`
            );
            const phpfmtFormatted: string = stdout.toString();
            assert.equal(doc.getText(), phpfmtFormatted);
          },
          err => console.error(err)
        )
      );
    });
  });

  test('should register commands', () => {
    return Commands.getCommands(true).then(commands => {
      const foundCommands = commands.filter(value =>
        value.startsWith('phpfmt.')
      );

      assert.equal(foundCommands.length, pkg.contributes.commands.length);
    });
  });

  test('should commands work', () => {
    const commands = pkg.contributes.commands as Array<any>;
    commands
      .filter(value => !value.when)
      .forEach(command => Commands.executeCommand(command.command));
  });
});
